@@ -7,7 +7,7 @@ use warnings;
 use NEXT;
 use Catalyst::Utils ();
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 sub setup_session {
     my $c = shift;
@@ -25,7 +25,7 @@ sub extend_session_id {
         $c->update_session_cookie( $c->make_session_cookie( $sid ) );
     }
 
-    $c->NEXT::extend_session_id( @_ );
+    $c->NEXT::extend_session_id( $sid, $expires );
 }
 
 sub set_session_id {
@@ -33,7 +33,7 @@ sub set_session_id {
 
     $c->update_session_cookie( $c->make_session_cookie( $sid ) );
 
-    return $c->NEXT::set_session_id(@_);
+    return $c->NEXT::set_session_id($sid);
 }
 
 sub update_session_cookie {
